@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -39,6 +41,13 @@ class ChangeRoomPlayerProfileRequest(AbstractModel):
         self.GameId = params.get("GameId")
         self.PlayerId = params.get("PlayerId")
         self.CustomProfile = params.get("CustomProfile")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ChangeRoomPlayerProfileResponse(AbstractModel):
@@ -87,6 +96,13 @@ class ChangeRoomPlayerStatusRequest(AbstractModel):
         self.GameId = params.get("GameId")
         self.CustomStatus = params.get("CustomStatus")
         self.PlayerId = params.get("PlayerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ChangeRoomPlayerStatusResponse(AbstractModel):
@@ -135,6 +151,13 @@ class DescribePlayerRequest(AbstractModel):
         self.GameId = params.get("GameId")
         self.OpenId = params.get("OpenId")
         self.PlayerId = params.get("PlayerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribePlayerResponse(AbstractModel):
@@ -183,6 +206,13 @@ class DescribeRoomRequest(AbstractModel):
         self.GameId = params.get("GameId")
         self.PlayerId = params.get("PlayerId")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRoomResponse(AbstractModel):
@@ -227,6 +257,13 @@ class DismissRoomRequest(AbstractModel):
     def _deserialize(self, params):
         self.GameId = params.get("GameId")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DismissRoomResponse(AbstractModel):
@@ -301,6 +338,13 @@ class ModifyRoomRequest(AbstractModel):
         self.IsPrivate = params.get("IsPrivate")
         self.CustomProperties = params.get("CustomProperties")
         self.IsForbidJoin = params.get("IsForbidJoin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyRoomResponse(AbstractModel):
@@ -365,6 +409,13 @@ class Player(AbstractModel):
         self.PlayerId = params.get("PlayerId")
         self.CustomPlayerStatus = params.get("CustomPlayerStatus")
         self.CustomProfile = params.get("CustomProfile")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemoveRoomPlayerRequest(AbstractModel):
@@ -386,6 +437,13 @@ class RemoveRoomPlayerRequest(AbstractModel):
     def _deserialize(self, params):
         self.GameId = params.get("GameId")
         self.RemovePlayerId = params.get("RemovePlayerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemoveRoomPlayerResponse(AbstractModel):
@@ -500,6 +558,13 @@ class Room(AbstractModel):
         self.StartGameTime = params.get("StartGameTime")
         self.IsForbidJoin = params.get("IsForbidJoin")
         self.Owner = params.get("Owner")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Team(AbstractModel):
@@ -528,4 +593,11 @@ class Team(AbstractModel):
         self.Id = params.get("Id")
         self.Name = params.get("Name")
         self.MinPlayers = params.get("MinPlayers")
-        self.MaxPlayers = params.get("MaxPlayers")
\ No newline at end of file
+        self.MaxPlayers = params.get("MaxPlayers")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
