@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class Conditions(AbstractModel):
     def _deserialize(self, params):
         self.Reason = params.get("Reason")
         self.Count = params.get("Count")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Config(AbstractModel):
@@ -81,6 +90,13 @@ class Config(AbstractModel):
         self.Version = params.get("Version")
         self.UpdateTime = params.get("UpdateTime")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateJobRequest(AbstractModel):
@@ -154,6 +170,13 @@ class CreateJobRequest(AbstractModel):
             self.QuantizationInput = QuantizationInput()
             self.QuantizationInput._deserialize(params.get("QuantizationInput"))
         self.LogTopicId = params.get("LogTopicId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateJobResponse(AbstractModel):
@@ -218,6 +241,13 @@ class CreateRsgAsGroupRequest(AbstractModel):
         self.Cluster = params.get("Cluster")
         self.Name = params.get("Name")
         self.DesiredSize = params.get("DesiredSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateRsgAsGroupResponse(AbstractModel):
@@ -274,6 +304,13 @@ class CreateRuntimeRequest(AbstractModel):
         self.Framework = params.get("Framework")
         self.Description = params.get("Description")
         self.HealthCheckOn = params.get("HealthCheckOn")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateRuntimeResponse(AbstractModel):
@@ -326,6 +363,13 @@ class CreateServiceConfigRequest(AbstractModel):
         self.Runtime = params.get("Runtime")
         self.ModelUri = params.get("ModelUri")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateServiceConfigResponse(AbstractModel):
@@ -420,6 +464,13 @@ class CreateServiceRequest(AbstractModel):
         self.Description = params.get("Description")
         self.GpuType = params.get("GpuType")
         self.LogTopicId = params.get("LogTopicId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateServiceResponse(AbstractModel):
@@ -460,6 +511,13 @@ class DeleteInstanceRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteInstanceResponse(AbstractModel):
@@ -494,6 +552,13 @@ class DeleteJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteJobResponse(AbstractModel):
@@ -528,6 +593,13 @@ class DeleteResourceGroupRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ResourceGroupId = params.get("ResourceGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteResourceGroupResponse(AbstractModel):
@@ -562,6 +634,13 @@ class DeleteRsgAsGroupRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Id = params.get("Id")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteRsgAsGroupResponse(AbstractModel):
@@ -596,6 +675,13 @@ class DeleteRuntimeRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Runtime = params.get("Runtime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteRuntimeResponse(AbstractModel):
@@ -634,6 +720,13 @@ class DeleteServiceConfigRequest(AbstractModel):
     def _deserialize(self, params):
         self.ServiceConfigId = params.get("ServiceConfigId")
         self.ServiceConfigName = params.get("ServiceConfigName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteServiceConfigResponse(AbstractModel):
@@ -668,6 +761,13 @@ class DeleteServiceRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ServiceId = params.get("ServiceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteServiceResponse(AbstractModel):
@@ -727,6 +827,13 @@ class DescribeInstancesRequest(AbstractModel):
         self.Order = params.get("Order")
         self.OrderField = params.get("OrderField")
         self.ResourceGroupId = params.get("ResourceGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeInstancesResponse(AbstractModel):
@@ -795,6 +902,13 @@ class DescribeResourceGroupsRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Order = params.get("Order")
         self.OrderField = params.get("OrderField")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeResourceGroupsResponse(AbstractModel):
@@ -876,6 +990,13 @@ class DescribeRsgAsGroupActivitiesRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Order = params.get("Order")
         self.OrderField = params.get("OrderField")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRsgAsGroupActivitiesResponse(AbstractModel):
@@ -945,6 +1066,13 @@ class DescribeRsgAsGroupsRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Order = params.get("Order")
         self.OrderField = params.get("OrderField")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRsgAsGroupsResponse(AbstractModel):
@@ -1054,6 +1182,13 @@ class DescribeServiceConfigsRequest(AbstractModel):
         self.Order = params.get("Order")
         self.OrderField = params.get("OrderField")
         self.PageByName = params.get("PageByName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeServiceConfigsResponse(AbstractModel):
@@ -1122,6 +1257,13 @@ class DescribeServicesRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Order = params.get("Order")
         self.OrderField = params.get("OrderField")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeServicesResponse(AbstractModel):
@@ -1169,6 +1311,13 @@ class DisableRsgAsGroupRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Id = params.get("Id")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableRsgAsGroupResponse(AbstractModel):
@@ -1203,6 +1352,13 @@ class EnableRsgAsGroupRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Id = params.get("Id")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableRsgAsGroupResponse(AbstractModel):
@@ -1266,6 +1422,13 @@ class ExposeInfo(AbstractModel):
         self.GateWayServiceId = params.get("GateWayServiceId")
         self.GateWayAPIId = params.get("GateWayAPIId")
         self.GateWayDomain = params.get("GateWayDomain")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ExposeServiceRequest(AbstractModel):
@@ -1295,6 +1458,13 @@ class ExposeServiceRequest(AbstractModel):
         self.ExposeType = params.get("ExposeType")
         self.VpcId = params.get("VpcId")
         self.SubnetId = params.get("SubnetId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ExposeServiceResponse(AbstractModel):
@@ -1339,6 +1509,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Instance(AbstractModel):
@@ -1428,6 +1605,13 @@ class Instance(AbstractModel):
         self.MemoryRequested = params.get("MemoryRequested")
         self.GpuRequested = params.get("GpuRequested")
         self.RsgAsGroupId = params.get("RsgAsGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Job(AbstractModel):
@@ -1567,6 +1751,13 @@ class Job(AbstractModel):
             self.QuantizationInput = QuantizationInput()
             self.QuantizationInput._deserialize(params.get("QuantizationInput"))
         self.LogTopicId = params.get("LogTopicId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class JobStatus(AbstractModel):
@@ -1614,6 +1805,13 @@ class JobStatus(AbstractModel):
                 obj = ReplicaInfo()
                 obj._deserialize(item)
                 self.ReplicaInfos.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModelService(AbstractModel):
@@ -1750,6 +1948,13 @@ class ModelService(AbstractModel):
         self.Description = params.get("Description")
         self.GpuType = params.get("GpuType")
         self.LogTopicId = params.get("LogTopicId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Option(AbstractModel):
@@ -1771,6 +1976,13 @@ class Option(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PredictInput(AbstractModel):
@@ -1809,6 +2021,13 @@ class PredictInput(AbstractModel):
         self.OutputDataFormat = params.get("OutputDataFormat")
         self.BatchSize = params.get("BatchSize")
         self.SignatureName = params.get("SignatureName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class QuantizationInput(AbstractModel):
@@ -1842,6 +2061,13 @@ class QuantizationInput(AbstractModel):
         self.BatchSize = params.get("BatchSize")
         self.Precision = params.get("Precision")
         self.ConvertType = params.get("ConvertType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ReplicaInfo(AbstractModel):
@@ -1887,6 +2113,13 @@ class ReplicaInfo(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.CreateTime = params.get("CreateTime")
         self.Restarted = params.get("Restarted")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ResourceGroup(AbstractModel):
@@ -1995,6 +2228,13 @@ class ResourceGroup(AbstractModel):
         self.GpuType = params.get("GpuType")
         self.HasPrepaid = params.get("HasPrepaid")
         self.PayMode = params.get("PayMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RsgAsActivityRelatedInstance(AbstractModel):
@@ -2016,6 +2256,13 @@ class RsgAsActivityRelatedInstance(AbstractModel):
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
         self.InstanceStatus = params.get("InstanceStatus")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RsgAsGroup(AbstractModel):
@@ -2085,6 +2332,13 @@ class RsgAsGroup(AbstractModel):
         self.InstanceType = params.get("InstanceType")
         self.InstanceCount = params.get("InstanceCount")
         self.DesiredSize = params.get("DesiredSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RsgAsGroupActivity(AbstractModel):
@@ -2151,6 +2405,13 @@ class RsgAsGroupActivity(AbstractModel):
                 obj._deserialize(item)
                 self.RsgAsActivityRelatedInstance.append(obj)
         self.StatusMessageSimplified = params.get("StatusMessageSimplified")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Runtime(AbstractModel):
@@ -2196,6 +2457,13 @@ class Runtime(AbstractModel):
         self.HealthCheckOn = params.get("HealthCheckOn")
         self.Image = params.get("Image")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Scaler(AbstractModel):
@@ -2230,6 +2498,13 @@ class Scaler(AbstractModel):
                 obj = Option()
                 obj._deserialize(item)
                 self.HpaMetrics.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ServiceStatus(AbstractModel):
@@ -2285,6 +2560,13 @@ class ServiceStatus(AbstractModel):
                 obj = ReplicaInfo()
                 obj._deserialize(item)
                 self.ReplicaInfos.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateJobRequest(AbstractModel):
@@ -2310,6 +2592,13 @@ class UpdateJobRequest(AbstractModel):
         self.JobId = params.get("JobId")
         self.JobAction = params.get("JobAction")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateJobResponse(AbstractModel):
@@ -2367,6 +2656,13 @@ class UpdateRsgAsGroupRequest(AbstractModel):
         self.MaxSize = params.get("MaxSize")
         self.MinSize = params.get("MinSize")
         self.DesiredSize = params.get("DesiredSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateRsgAsGroupResponse(AbstractModel):
@@ -2449,6 +2745,13 @@ class UpdateServiceRequest(AbstractModel):
         self.Memory = params.get("Memory")
         self.Gpu = params.get("Gpu")
         self.LogTopicId = params.get("LogTopicId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateServiceResponse(AbstractModel):
